@@ -3,7 +3,6 @@ from django.conf import settings
 from django.db import models
 from django.utils.safestring import mark_safe
 from django.utils.html import escape
-from django.utils.encoding import python_2_unicode_compatible
 
 from markupfield import widgets
 from markupfield import markup
@@ -15,7 +14,6 @@ _markup_type_field_name = lambda name: '%s_markup_type' % name
 _MARKUP_TYPES = getattr(settings, 'MARKUP_FIELD_TYPES', markup.DEFAULT_MARKUP_TYPES)
 
 
-@python_2_unicode_compatible
 class Markup(object):
 
     def __init__(self, instance, field_name, rendered_field_name,
@@ -51,7 +49,7 @@ class Markup(object):
     rendered = property(_get_rendered)
 
     # allows display via templates to work without safe filter
-    def __str__(self):
+    def __unicode__(self):
         return mark_safe(self.rendered)
 
 
@@ -95,7 +93,7 @@ class MarkupField(models.TextField):
 
         # pre-1.0 markup_choices might have been a dict
         if isinstance(markup_choices, dict):
-            raise ValueError('passing a dict as markup_choices removed in 1.1')
+            raise ValueError('passing a dictionary as markup_choices is deprecated')
         else:
             self.markup_choices_list = [mc[0] for mc in markup_choices]
             self.markup_choices_dict = dict(markup_choices)
@@ -115,13 +113,14 @@ class MarkupField(models.TextField):
 
     def contribute_to_class(self, cls, name):
         if not cls._meta.abstract:
-            choices = zip(self.markup_choices_list, self.markup_choices_list)
+            choices = zip([''] + self.markup_choices_list,
+                          ['--'] + self.markup_choices_list)
             markup_type_field = models.CharField(max_length=30,
                 choices=choices, default=self.default_markup_type,
                 editable=self.markup_type_editable, blank=self.blank)
             rendered_field = models.TextField(editable=False)
-            markup_type_field.creation_counter = self.creation_counter+1
-            rendered_field.creation_counter = self.creation_counter+2
+            markup_type_field.creation_counter = self.creation_counter + 1
+            rendered_field.creation_counter = self.creation_counter + 2
             cls.add_to_class(_markup_type_field_name(name), markup_type_field)
             cls.add_to_class(_rendered_field_name(name), rendered_field)
         super(MarkupField, self).contribute_to_class(cls, name)
@@ -149,7 +148,7 @@ class MarkupField(models.TextField):
             return value
 
     # copy get_prep_value to get_db_prep_value if pre-1.2
-    if django.VERSION < (1,2):
+    if django.VERSION < (1, 2):
         get_db_prep_value = get_prep_value
 
     def value_to_string(self, obj):
@@ -172,7 +171,7 @@ try:
     # always True, which means no_rendered_field arg will always be
     # True in a frozen MarkupField, which is what we want.
     add_introspection_rules(rules=[
-        ( (MarkupField,), [], { 'rendered_field': ['rendered_field', {}], })
+        ((MarkupField, ), [], {'rendered_field': ['rendered_field', {}], })
     ], patterns=['markupfield\.fields\.MarkupField'])
 except ImportError:
     pass
