@@ -21,4 +21,4 @@ INSTALLED_APPS = (
     'markupfield.tests',
 )
 
-SECRET_KEY = 'not-so-secret'
+SECRET_KEY = 'sekrit'
